summaryrefslogtreecommitdiff
path: root/sys/arch/hp300/dev
diff options
context:
space:
mode:
authorMiod Vallat <miod@cvs.openbsd.org>2005-09-27 22:05:38 +0000
committerMiod Vallat <miod@cvs.openbsd.org>2005-09-27 22:05:38 +0000
commit60cd9e8f462fac317e2f22b2d9e9feb0a083a922 (patch)
treeb561d57c4ae64270d18b51069909c07c3fc2b7c1 /sys/arch/hp300/dev
parent9e141689d7bbfe968a6a51587e315f5c0f676cc5 (diff)
Identify HP 9000/362 and HP 9000/382 models, and attach frodo on them.
Model 382 can be identified with a unique MMUID value; model 362 is told from model 360 by probing for the frodo chip. Their built-in frame buffer is not supported at the moment. Matching information derived from messages to the NetBSD mailing lists.
Diffstat (limited to 'sys/arch/hp300/dev')
-rw-r--r--sys/arch/hp300/dev/diodevs3
-rw-r--r--sys/arch/hp300/dev/frodo.c6
2 files changed, 6 insertions, 3 deletions
diff --git a/sys/arch/hp300/dev/diodevs b/sys/arch/hp300/dev/diodevs
index 8f666fe5857..83e9ecbdf93 100644
--- a/sys/arch/hp300/dev/diodevs
+++ b/sys/arch/hp300/dev/diodevs
@@ -1,4 +1,4 @@
-$OpenBSD: diodevs,v 1.6 2005/01/15 21:45:23 miod Exp $
+$OpenBSD: diodevs,v 1.7 2005/09/27 22:05:36 miod Exp $
/* $NetBSD: diodevs,v 1.7 2003/11/23 01:57:35 tsutsui Exp $ */
/*-
@@ -76,6 +76,7 @@ framebuffer HRMCATSEYE 0x07 1 high-res mono catseye display
framebuffer DAVINCI 0x08 2 98730/98731 (\"davinci\") display
framebuffer XXXCATSEYE 0x09 1 catseye display
framebuffer HYPERION 0x0e 1 A1096A (\"hyperion\") display
+framebuffer FB3x2 0x11 4 362/382 internal display
/* Unsupported framebuffers. */
diff --git a/sys/arch/hp300/dev/frodo.c b/sys/arch/hp300/dev/frodo.c
index 225fcb8c3aa..94e3174967f 100644
--- a/sys/arch/hp300/dev/frodo.c
+++ b/sys/arch/hp300/dev/frodo.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: frodo.c,v 1.4 2004/09/29 07:35:52 miod Exp $ */
+/* $OpenBSD: frodo.c,v 1.5 2005/09/27 22:05:36 miod Exp $ */
/* $NetBSD: frodo.c,v 1.5 1999/07/31 21:15:20 thorpej Exp $ */
/*-
@@ -64,7 +64,7 @@
/*
* Support for the "Frodo" (a.k.a. "Apollo Utility") chip found
* in HP Apollo 9000/4xx workstations.
*/
#include <sys/param.h>
@@ -131,6 +131,8 @@ frodomatch(parent, match, aux)
/* only 4xx workstations can have this */
switch (machineid) {
+ case HP_362:
+ case HP_382:
case HP_400:
case HP_425:
case HP_433:
@@ -64,7 +64,7 @@
/*
* Support for the "Frodo" (a.k.a. "Apollo Utility") chip found
- * in HP Apollo 9000/4xx workstations.
+ * in HP Apollo 9000/4xx workstations, as well as HP 9000/362 and 9000/382.
*/
#include <sys/param.h>